A schema layer harmoniously brings together the best of the flexibility ("anything goes!") of graph databases  
and the "law and order" aspect of relational databases!


* [Motivation and Overview](https://julianspolymathexplorations.blogspot.com/2022/11/schema-graph-databases-neo4j.html)

* [User Guide](https://brainannex.org/docs/neoschema-user-guide.htm)

* [Reference Guide](https://brainannex.org/docs/neoschema.htm)
